pub struct KeyModifiers(/* private fields */);Expand description
Represents key modifiers (shift, control, alt, etc.).
Note: SUPER, HYPER, and META can only be read if
KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with
PushKeyboardEnhancementFlags.
Implementations
Sourceimpl KeyModifiers
impl KeyModifiers
pub const SHIFT: KeyModifiers
pub const CONTROL: KeyModifiers
pub const ALT: KeyModifiers
pub const SUPER: KeyModifiers
pub const HYPER: KeyModifiers
pub const META: KeyModifiers
pub const NONE: KeyModifiers
Sourceimpl KeyModifiers
impl KeyModifiers
Sourcepub const fn empty() -> KeyModifiers
pub const fn empty() -> KeyModifiers
Get a flags value with all bits unset.
Sourcepub const fn all() -> KeyModifiers
pub const fn all() -> KeyModifiers
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<KeyModifiers>
pub const fn from_bits(bits: u8) -> Option<KeyModifiers>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> KeyModifiers
pub const fn from_bits_truncate(bits: u8) -> KeyModifiers
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> KeyModifiers
pub const fn from_bits_retain(bits: u8) -> KeyModifiers
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<KeyModifiers>
pub fn from_name(name: &str) -> Option<KeyModifiers>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: KeyModifiers) -> bool
pub const fn intersects(&self, other: KeyModifiers) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: KeyModifiers) -> bool
pub const fn contains(&self, other: KeyModifiers) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: KeyModifiers)
pub fn insert(&mut self, other: KeyModifiers)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: KeyModifiers)
pub fn remove(&mut self, other: KeyModifiers)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: KeyModifiers)
pub fn toggle(&mut self, other: KeyModifiers)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: KeyModifiers, value: bool)
pub fn set(&mut self, other: KeyModifiers, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: KeyModifiers) -> KeyModifiers
pub const fn intersection(self, other: KeyModifiers) -> KeyModifiers
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: KeyModifiers) -> KeyModifiers
pub const fn union(self, other: KeyModifiers) -> KeyModifiers
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: KeyModifiers) -> KeyModifiers
pub const fn difference(self, other: KeyModifiers) -> KeyModifiers
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: KeyModifiers) -> KeyModifiers
pub const fn symmetric_difference(self, other: KeyModifiers) -> KeyModifiers
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> KeyModifiers
pub const fn complement(self) -> KeyModifiers
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl KeyModifiers
impl KeyModifiers
Sourcepub const fn iter(&self) -> Iter<KeyModifiers>
pub const fn iter(&self) -> Iter<KeyModifiers>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<KeyModifiers>
pub const fn iter_names(&self) -> IterNames<KeyModifiers>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.